import * as eks from '@aws-cdk/aws-eks';
import { PostgresEngineVersion } from '@aws-cdk/aws-rds';
/**
 * @stability stable
 */
export interface KongEksControlPlaneProps {
    /**
     * @stability stable
     */
    readonly clusterDns: String;
    /**
     * @stability stable
     */
    readonly telemetryDns: String;
    /**
     * @stability stable
     */
    readonly namespace: string;
    /**
     * @see https://docs.aws.amazon.com/cdk/api/latest/docs/
     * @stability stable
     * @summary Control Plane EKS Cluster properties
     * @aws-cdk_aws-eks .ClusterProps.html
     */
    readonly controlPlaneClusterProps: eks.ClusterProps;
    /**
     * @stability stable
     * @summary RDS Database properties
     */
    readonly rdsProps: RdsDatabaseProps;
    /**
     * @see https://docs.aws.amazon.com/cdk/api/latest/docs/
     * @stability stable
     * @summary Kong Control Plane EKS Nodes properties
     * @aws-cdk_aws-eks .AutoScalingGroupCapacityOptions.html
     */
    readonly controlPlaneNodeProps: eks.AutoScalingGroupCapacityOptions;
}
/**
 * @stability stable
 */
export interface RdsDatabaseProps {
    /**
     * @see https://docs.aws.amazon.com/cdk/api/latest/docs/
     * @stability stable
     * @summary RDS PostGres Engine Version
     * @aws-cdk_aws-rds .PostgresEngineVersion.html
     */
    readonly postgresversion: PostgresEngineVersion;
    /**
     * @stability stable
     * @summary Master username to be used for RDS
     */
    readonly username: string;
    /**
     * @stability stable
     * @summary Database name to be used for Artifactory
     */
    readonly databasename: string;
}
